@@ -1,4 +1,4 @@
-from .client import APIClient, ProductionAPIClient, DevelopmentAPIClient  # noqa: F401
+from .client import APIClient, ProductionAPIClient, DevelopmentAPIClient, RtemClient  # noqa: F401
 from .exceptions import OnboardApiException, OnboardTemporaryException
 
 OnboardClient = ProductionAPIClient
@@ -6,6 +6,7 @@ OnboardClient = ProductionAPIClient
 __all__ = [
     'OnboardClient',
     'APIClient',
+    'RtemClient',
     'OnboardApiException',
     'OnboardTemporaryException'
 ]
